..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Discussion Questions
--------------------

#. Draw a call stack for the Tower of Hanoi problem. Assume that you
   start with a stack of three disks.

#. Using the recursive rules as described, draw a
   Sierpinski triangle using paper and pencil.

#. Using the dynamic programming algorithm for making change, find the
   smallest number of coins that you can use to make 33 cents in change.
   In addition to the usual coins assume that you have an 8 cent coin.
